@@ -42,6 +42,8 @@ class RepeatSwitcherWidget(hildondesktop.StatusMenuItem):
 
     def on_toggled(self, widget):
         self._client.set_bool(self.KEY, widget.get_active())
+        # Hide the status menu after the buttons have been toggled
+        widget.get_toplevel().hide()
 
 hd_plugin_type = RepeatSwitcherWidget
 
